pub struct Request<A, R> {
    pub responder: Sender<R>,
    pub arguments: A,
}
Asynchronous request sent to the service.

Fields

responder: Sender<R>

Oneshot channel for the service to send back the response.

arguments: A

Request arguments.

Implementations

Call the service with the arguments and wait for the response.